part of "./side_nav.dart";

class _NavView extends StatefulWidget {
  /// 导航Id
  final int navId;

  /// 菜单项集合
  final List<VSideNavMenuItem> items;

  final VSideNavViewController controller;

  const _NavView({
    required this.navId,
    required this.items,
    required this.controller,
  });

  @override
  State<StatefulWidget> createState() => _NavViewState();
}

class NavigatorObserverS extends NavigatorObserver {}

class _NavViewState extends State<_NavView> {
  @override
  Widget build(BuildContext context) {
    return Container(
      child: _buildNavigator(context),
    );
  }

  Widget _buildNavigator(BuildContext context) {
    return Navigator(
      key: Get.nestedKey(widget.navId),
      initialRoute: widget.controller.currentRoute,
      onGenerateRoute: onGenerateRoute,
    );
  }

  /// 路由生成器
  Route? onGenerateRoute(RouteSettings settings) {
    String? name = settings.name;
    if (name == null) return null;

    final item = widget.items.firstWhereOrNull((e) => e.route?.name == name);
    if (item == null) return null;

    final route = item.route!;

    widget.controller.routeChangedEvent.emit(this, route.name);

    return GetPageRoute(
      page: route.page,
      binding: route.binding,
      customTransition: FTransitions.sharedAxisHorizontal,
      transitionDuration: GlobalStyles.navTransitionDuration,
    );
  }
}
