import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vnoteapp/components/cell.dart';
import 'package:vnoteapp/consts/styles.dart';
import 'package:vnoteapp/routes/transition.dart';

import 'controller.dart';
import 'defines.dart';

part 'nav_view.dart';
part 'side_bar.dart';

class VSideNavView extends StatefulWidget {
  /// 导航Id
  final int navId;

  /// 菜单项集合
  final List<VSideNavMenuItem> items;

  final VSideNavViewController? controller;

  final int leftFlex;
  final int rightFlex;

  const VSideNavView({
    super.key,
    required this.navId,
    required this.items,
    this.controller,
    this.leftFlex = 1,
    this.rightFlex = 2,
  });

  @override
  State<StatefulWidget> createState() => _VSideNavViewState();
}

class _VSideNavViewState extends State<VSideNavView> {
  late final VSideNavViewController controller;
  @override
  void initState() {
    controller = widget.controller ?? VSideNavViewController();
    _initRoute();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final sideView = _SideBar(
      controller: controller,
      items: widget.items,
      navId: widget.navId,
    );
    final navView = _NavView(
      controller: controller,
      items: widget.items,
      navId: widget.navId,
    );

    return Container(
      child: Row(
        children: [
          Expanded(
            flex: widget.leftFlex,
            child: sideView,
          ),
          const VerticalDivider(width: 1),
          Expanded(
            flex: widget.rightFlex,
            child: navView,
          ),
        ],
      ),
    );
  }

  void _initRoute() {
    final firstRouteItem =
        widget.items.firstWhereOrNull((e) => e.route != null);

    final firstRoute = firstRouteItem?.route;
    controller.routeChangedEvent.emit(this, firstRoute?.name);
  }
}
