import 'package:fis_jsonrpc/rpc.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vnoteapp/components/alert_dialog.dart';
import 'package:vnoteapp/pages/contract/package_list/controller.dart';

class FamilyDoctorServicePackagePage
    extends GetView<ServicePackageContractController> {
  const FamilyDoctorServicePackagePage({super.key});

  @override
  Widget build(BuildContext context) {
    return buildServicePackageList(context);
  }

  Widget buildAlertDialog(ServicePackDTO servicePackDTO) {
    return VAlertDialog(
      title: '${servicePackDTO.name}详情',
      content: Container(
          height: 200,
          alignment: Alignment.topLeft,
          padding: const EdgeInsets.symmetric(horizontal: 15),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              LayoutBuilder(
                builder: (BuildContext context, BoxConstraints constraints) {
                  return ConstrainedBox(
                    constraints: const BoxConstraints(
                      maxHeight: 100,
                    ),
                    child: Scrollbar(
                      thumbVisibility: true,
                      child: ListView(
                        shrinkWrap: true,
                        children: [
                          Text(
                            servicePackDTO.content ?? "",
                            style: const TextStyle(fontSize: 16),
                          ),
                        ],
                      ),
                    ),
                  );
                },
              ),
              const SizedBox(
                height: 5,
              ),
              const Text(
                '服务项目',
                style: TextStyle(fontWeight: FontWeight.bold, fontSize: 18),
              ),
              const SizedBox(
                height: 5,
              ),
              Expanded(
                child: Text(
                  controller.getServiceItemsName(
                    servicePackDTO.items ?? [],
                  ),
                ),
              )
            ],
          )),
      // actions: <Widget>[
      //   TextButton(
      //     child: const Text('取消'),
      //     onPressed: () {
      //       Navigator.of(context).pop(); // 关闭对话框
      //     },
      //   ),
      //   TextButton(
      //     child: const Text('确定'),
      //     onPressed: () {
      //       // 在这里处理确定按钮的逻辑
      //       Navigator.of(context).pop(); // 关闭对话框
      //     },
      //   ),
      // ],
    );
  }

  Widget buildItem(ServicePackDTO servicePackDTO, BuildContext context) {
    return InkWell(
      onTap: () {
        controller.changeServicePackage(servicePackDTO);
      },
      child: Container(
        margin: const EdgeInsets.symmetric(
          vertical: 10,
          horizontal: 50,
        ),
        padding: const EdgeInsets.symmetric(horizontal: 30, vertical: 15),
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: const BorderRadius.all(
            Radius.circular(
              8,
            ),
          ),
          border: Border.all(
            color:
                controller.state.selectedServicePackage.contains(servicePackDTO)
                    ? Theme.of(context).primaryColor
                    : Colors.transparent,
            width: 2,
          ),
        ),
        child: Row(
          children: [
            Container(
              padding: const EdgeInsets.only(right: 20),
              child: Obx(
                () => Icon(
                  Icons.check_circle_outline,
                  size: 35,
                  color: controller.state.selectedServicePackage
                          .contains(servicePackDTO)
                      ? Theme.of(context).primaryColor
                      : Colors.grey.shade500,
                ),
              ),
            ),
            Expanded(
              child: Column(
                children: [
                  Row(
                    children: [
                      Expanded(
                        child: Text(
                          servicePackDTO.name ?? '',
                          style: const TextStyle(
                            fontSize: 25,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                      ),
                      Expanded(
                        child: Row(
                          children: [
                            const Text(
                              '服务人群：',
                              style: TextStyle(fontSize: 20),
                            ),
                            Text(
                              controller.setNormalLabels(
                                servicePackDTO.labels ?? [],
                              ),
                              style: const TextStyle(fontSize: 18),
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 10,
                  ),
                  Row(
                    mainAxisSize: MainAxisSize.max,
                    children: [
                      Expanded(
                        child: Row(
                          mainAxisSize: MainAxisSize.max,
                          children: [
                            const Text(
                              '服务包介绍：',
                              style: TextStyle(fontSize: 18),
                            ),
                            Expanded(
                              child: Container(
                                alignment: Alignment.centerLeft,
                                height: 50,
                                child: Text(
                                  servicePackDTO.content ?? '',
                                  overflow: TextOverflow.ellipsis,
                                  maxLines: 2,
                                  style: const TextStyle(fontSize: 18),
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ],
              ),
            ),
            Container(
              padding: const EdgeInsets.only(left: 20),
              child: TextButton(
                child: const Text(
                  '查看',
                  style: TextStyle(fontSize: 18),
                ),
                onPressed: () async {
                  // await Get.toNamed(
                  //   '/contract/package_info',
                  //   parameters: {
                  //     "servicePack": json.encode(servicePackDTO.toJson()),
                  //   },
                  // );
                  showDialog(
                    context: context,
                    builder: (BuildContext context) {
                      return buildAlertDialog(servicePackDTO);
                    },
                  );
                },
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget buildServicePackageList(BuildContext context) {
    return Obx(
      () => Expanded(
        child: controller.state.servicePackageItems.isEmpty
            ? Container(
                margin: const EdgeInsets.only(top: 80),
                child: Column(
                  children: [
                    Center(
                      child: Image.asset(
                        "assets/images/no_data.png",
                        width: 300,
                        height: 300,
                        fit: BoxFit.cover,
                      ),
                    ),
                    const Text(
                      "暂无数据，先看看别的吧",
                      style: TextStyle(fontSize: 18),
                    ),
                  ],
                ),
              )
            : ListView(
                children: controller.state.servicePackageItems
                    .map((ServicePackDTO e) => buildItem(e, context))
                    .toList(),
              ),
      ),
    );
  }
}
